"use strict";

exports.__esModule = true;
exports.default = void 0;

var _path = require("path");

var _utils = require("./utils");

// require('debug-utils').install();
const resolveDirname = (path, opts, fileOpts) => {
  const _opts$ignoreDirWithDo = opts.ignoreDirWithDots,
        ignoreDirWithDots = _opts$ignoreDirWithDo === void 0 ? true : _opts$ignoreDirWithDo,
        moduleFileExtensions = opts.moduleFileExtensions;
  const filename = fileOpts.filename; // Only process absolute or relative paths without extensions (eg. exclude regular modules)

  const hasExtension = !!(0, _path.extname)(path);
  const isAbsolutePath = (0, _path.isAbsolute)(path);
  const isRelativePath = (0, _utils.isRelative)(path);

  if (ignoreDirWithDots && hasExtension || !(isAbsolutePath || isRelativePath)) {
    return path;
  }

  const fileDirname = (0, _path.dirname)(filename); // Do we have a matching directory?

  const targetPath = isRelativePath ? (0, _path.resolve)(fileDirname, path) : path;

  if (!(0, _utils.isDirectory)(targetPath)) {
    return path;
  } // Without any index file?


  const fileExtname = (0, _path.extname)(filename);
  const fileExtensions = moduleFileExtensions || [fileExtname ? fileExtname.slice(1) : fileExtname]; // Enable support for custom extensions

  for (var _iterator = fileExtensions, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
    var _ref;

    if (_isArray) {
      if (_i >= _iterator.length) break;
      _ref = _iterator[_i++];
    } else {
      _i = _iterator.next();
      if (_i.done) break;
      _ref = _i.value;
    }

    const extension = _ref;

    if ((0, _utils.isFile)((0, _path.join)(targetPath, `index.${extension}`))) {
      return `${path}/index.${extension}`;
    }
  } // Without conflicting file that should have priority?


  const pathBasename = (0, _path.basename)(path);
  const targetPathDirname = (0, _path.dirname)(targetPath);

  if ((0, _utils.isFile)((0, _path.join)(targetPathDirname, `${pathBasename}${fileExtname}`))) {
    return path;
  } // Finally activate plugin as a last attempt


  return `${path}/${pathBasename}`;
};

var _default = ({
  types: t
}) => {
  const visitor = {
    CallExpression(path, state) {
      if (!(path.node.callee.name === 'require' || t.isImport(path.node.callee))) {
        return;
      }

      const args = path.node.arguments;

      if (!args.length) {
        return;
      }

      const firstArg = (0, _utils.traverseExpression)(t, args[0]);

      if (firstArg) {
        firstArg.value = resolveDirname(firstArg.value, state.opts, state.file.opts);
      }
    },

    ImportDeclaration(path, state) {
      path.node.source.value = resolveDirname(path.node.source.value, state.opts, state.file.opts); // eslint-disable-line no-param-reassign
    },

    ExportNamedDeclaration(path, state) {
      if (path.node.source) {
        path.node.source.value = resolveDirname(path.node.source.value, state.opts, state.file.opts); // eslint-disable-line no-param-reassign
      }
    },

    ExportAllDeclaration(path, state) {
      if (path.node.source) {
        path.node.source.value = resolveDirname(path.node.source.value, state.opts, state.file.opts); // eslint-disable-line no-param-reassign
      }
    }

  };
  return {
    visitor: {
      Program(path, state) {
        path.traverse(visitor, state);
      }

    }
  };
};

exports.default = _default;
//# sourceMappingURL=index.js.map